//!
//! For connecting nodes over
//! a network
//!
pub mod peer;
pub mod server;

#[cfg(test)]
mod tests {

    #[test]
    fn test_server_setup() {}
}
